@@ -8,19 +8,26 @@
 
 #include "declarativeadapter.h"
 #include "declarativedevice.h"
-
-static int devicesCountFunction(QQmlListProperty<DeclarativeDevice> *property)
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+static qsizetype devicesCountDeclarativeAdapterFunction(QQmlListProperty<DeclarativeDevice> *property)
+#else
+static int devicesCountDeclarativeAdapterFunction(QQmlListProperty<DeclarativeDevice> *property)
+#endif
 {
-    Q_ASSERT(qobject_cast<DeclarativeAdapter*>(property->object));
-    DeclarativeAdapter *adapter = static_cast<DeclarativeAdapter*>(property->object);
+    Q_ASSERT(qobject_cast<DeclarativeAdapter *>(property->object));
+    DeclarativeAdapter *adapter = static_cast<DeclarativeAdapter *>(property->object);
 
     return adapter->m_devices.count();
 }
 
-static DeclarativeDevice *devicesAtFunction(QQmlListProperty<DeclarativeDevice> *property, int index)
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+static DeclarativeDevice *devicesAtDeclarativeAdapterFunction(QQmlListProperty<DeclarativeDevice> *property, qsizetype index)
+#else
+static DeclarativeDevice *devicesAtDeclarativeAdapterFunction(QQmlListProperty<DeclarativeDevice> *property, int index)
+#endif
 {
-    Q_ASSERT(qobject_cast<DeclarativeAdapter*>(property->object));
-    DeclarativeAdapter *adapter = static_cast<DeclarativeAdapter*>(property->object);
+    Q_ASSERT(qobject_cast<DeclarativeAdapter *>(property->object));
+    DeclarativeAdapter *adapter = static_cast<DeclarativeAdapter *>(property->object);
 
     return adapter->m_devices.values().at(index);
 }
@@ -154,7 +161,7 @@ QString DeclarativeAdapter::modalias() const
 
 QQmlListProperty<DeclarativeDevice> DeclarativeAdapter::devices()
 {
-    return QQmlListProperty<DeclarativeDevice>(this, nullptr, devicesCountFunction, devicesAtFunction);
+    return QQmlListProperty<DeclarativeDevice>(this, nullptr, devicesCountDeclarativeAdapterFunction, devicesAtDeclarativeAdapterFunction);
 }
 
 DeclarativeDevice *DeclarativeAdapter::deviceForAddress(const QString &address) const
